StreamingChunker

Struct StreamingChunker 

pub struct StreamingChunker { /* private fields */ }
Stateful streaming chunker – feeds data incrementally, emits chunks as boundaries are found.

Unlike chunk_slice() which needs the full data in memory, StreamingChunker processes data in arbitrary-sized reads and emits Chunk objects as gear-hash boundaries are detected.

Example

let mut sc = StreamingChunker::new(&GearChunker::new(2048, 65536, 2097152).unwrap());
let mut file = std::fs::File::open("large_file.dat").unwrap();
let mut buf = [0u8; 1_048_576]; // 1MB read buffer
use std::io::Read;
loop {
    let n = file.read(&mut buf).unwrap();
    if n == 0 { break; }
    for chunk in sc.feed(&buf[..n]) {
        // Process each chunk (upload, hash, etc.)
    }
}
let (final_chunk, _file_hash) = sc.finish();

Implementations

Source

impl StreamingChunker

pub fn new(chunker: &GearChunker) -> Self

Create a new streaming chunker from a GearChunker configuration.

pub fn feed(&mut self, data: &[u8]) -> Vec<Chunk>

Feed data into the chunker and return any completed chunks.

pub fn finish(self) -> (Option<Chunk>, Hash)

Finish the stream and return any trailing data as a final chunk.

Returns None if no data remains after the last boundary. Also returns the whole-file BLAKE3 hash.

pub fn buffered(&self) -> usize

Get the current buffer size (bytes accumulated for current chunk).